import {
  usePhantom
} from "../chunk-5KSEZ3MC.mjs";

// src/solana/index.ts
import "@phantom/browser-sdk/solana";

// src/solana/useConnect.ts
import * as React from "react";
function useConnect({ autoConnect = false } = {}) {
  const { phantom } = usePhantom();
  const connect = React.useCallback(async () => {
    if (!phantom?.solana) {
      throw new Error("Phantom solana plugin not found.");
    }
    return await phantom.solana.connect();
  }, [phantom]);
  React.useEffect(() => {
    if (autoConnect && phantom?.solana) {
      connect();
    }
  }, [autoConnect, connect, phantom?.solana]);
  return { connect };
}

// src/solana/useDisconnect.ts
import * as React2 from "react";
function useDisconnect() {
  const { phantom } = usePhantom();
  const disconnect = React2.useCallback(async () => {
    if (!phantom?.solana) {
      throw new Error("Phantom solana disconnect method not found.");
    }
    return await phantom.solana.disconnect();
  }, [phantom]);
  return { disconnect };
}

// src/solana/useSignIn.ts
import { useCallback as useCallback3 } from "react";
function useSignIn() {
  const { phantom } = usePhantom();
  const signIn = useCallback3(
    async (signInData) => {
      if (!phantom?.solana) {
        throw new Error("Phantom Solana provider not available.");
      }
      const result = await phantom.solana.signIn(signInData);
      return result;
    },
    [phantom]
  );
  return { signIn };
}

// src/solana/useSignAndSendTransaction.ts
import { useCallback as useCallback4 } from "react";
function useSignAndSendTransaction() {
  const { phantom } = usePhantom();
  const signAndSendTransaction = useCallback4(
    async (transaction) => {
      if (!phantom?.solana) {
        throw new Error("Phantom Solana provider not available.");
      }
      const result = await phantom.solana.signAndSendTransaction(transaction);
      return result;
    },
    [phantom]
  );
  return { signAndSendTransaction };
}

// src/solana/useSignMessage.ts
import { useCallback as useCallback5 } from "react";
function useSignMessage() {
  const { phantom } = usePhantom();
  const signMessage = useCallback5(
    async (message, display) => {
      if (!phantom?.solana) {
        throw new Error("Phantom Solana provider not available.");
      }
      const result = await phantom.solana.signMessage(message, display);
      return result;
    },
    [phantom]
  );
  return { signMessage };
}

// src/solana/useAccount.ts
import * as React3 from "react";

// src/solana/assertions.ts
function assertSolanaConfigured(phantom) {
  if (!phantom?.solana) {
    throw new Error(
      "Phantom solana chain plugin not found. Please ensure the solana chain plugin is installed and configured properly."
    );
  }
}

// src/solana/useAccount.ts
function useAccount() {
  const { phantom, isReady } = usePhantom();
  const [account, setAccount] = React3.useState(void 0);
  React3.useEffect(() => {
    if (!isReady)
      return;
    assertSolanaConfigured(phantom);
    const updateAccount = async () => {
      setAccount(await phantom.solana.getAccount());
    };
    updateAccount();
    phantom.solana.addEventListener("connect", updateAccount);
    phantom.solana.addEventListener("disconnect", updateAccount);
    phantom.solana.addEventListener("accountChanged", updateAccount);
    return () => {
      phantom.solana.removeEventListener("connect", updateAccount);
      phantom.solana.removeEventListener("disconnect", updateAccount);
      phantom.solana.removeEventListener("accountChanged", updateAccount);
    };
  }, [phantom, isReady]);
  return account;
}

// src/solana/useAccountEffect.ts
import * as React4 from "react";
function useAccountEffect(parameters = {}) {
  const { onConnect, onDisconnect, onAccountChanged } = parameters;
  const { phantom, isReady } = usePhantom();
  React4.useEffect(() => {
    if (!isReady)
      return;
    assertSolanaConfigured(phantom);
    const handleConnect = (publicKey) => {
      onConnect?.({
        publicKey
      });
    };
    const handleDisconnect = () => {
      onDisconnect?.();
    };
    const handleAccountChanged = (publicKey) => {
      onAccountChanged?.({
        publicKey
      });
    };
    if (onConnect) {
      phantom.solana.addEventListener("connect", handleConnect);
    }
    if (onDisconnect) {
      phantom.solana.addEventListener("disconnect", handleDisconnect);
    }
    if (onAccountChanged) {
      phantom.solana.addEventListener("accountChanged", handleAccountChanged);
    }
    return () => {
      if (onConnect) {
        phantom.solana.removeEventListener("connect", handleConnect);
      }
      if (onDisconnect) {
        phantom.solana.removeEventListener("disconnect", handleDisconnect);
      }
      if (onAccountChanged) {
        phantom.solana.removeEventListener("accountChanged", handleAccountChanged);
      }
    };
  }, [isReady, phantom, onConnect, onDisconnect, onAccountChanged]);
}
export {
  useAccount,
  useAccountEffect,
  useConnect,
  useDisconnect,
  useSignAndSendTransaction,
  useSignIn,
  useSignMessage
};
